blok3d: Draw hespdiv polygons in 3D space

View source: R/block3D.R

blok3dR Documentation

Draw hespdiv polygons in 3D space

Description

This function visualizes HespDiv polygons in 3D space. The height axis corresponds to a chosen column from the "poly.stats" data frame.

Usage

blok3d(
  obj,
  height = "mean",
  color.seed = 1,
  lines = TRUE,
  pnts.col = NULL,
  obs = TRUE
)

Arguments

obj

An object of the hespdiv class

height

A character vector with default value "mean". Determines which information from the poly.stats data frame is encoded as the height of the polygons. Options are "mean", "sd", "best", "z.score", "str.best", "str.z.score", and "rank". Multiple values are allowed.

color.seed

An integer that controls the colors of the polygons. Change it to a different number if you want to get a different set of colors.

lines

A Boolean value. Do you want split-lines to be displayed over the top of the polygons?

pnts.col

A character or numeric vector. Color codes to be used for displaying observations.

obs

A Boolean value. Do you want observations to be displayed over the top of the polygons?

Details

The function opens an rgl device for each selected column of the poly.stats data frame.

Visualizing values from poly.stats as polygon height can provide insight into spatial heterogeneity in the analyzed data and its hierarchical spatial structure.

The height = "rank" option provides a more intuitive way to understand the position of each polygon in the spatial hierarchy than poly_scheme().

Because higher-rank polygons are displayed above lower-rank polygons, they may obscure the view. For this reason, polypop(obj, height) can be used with the same arguments to interactively select unwanted polygons and remove them from the actives plot.

Value

No return value. Called for the side effect of producing a 3D plot using the rgl graphics engine.

Author(s)

Liudas Daumantas

See Also

Other HespDiv visualization options: create_gif(), dendro(), plot.nullhespdiv(), plot_cs_hsa(), plot_hespdiv(), plot_hsa(), plot_hsa_q(), poly_scheme(), polypop()


hespdiv documentation built on May 21, 2026, 5:09 p.m.