change_base: Change the basal subdivision in hsa

View source: R/change_base.R

change_baseR Documentation

Change the basal subdivision in hsa

Description

This function allows you to select a new basal subdivision from the results of hespdiv sensitivity analysis by specifying its ID. It provides a convenient way to switch between different basal subdivisions. You can identify a more stable subdivision alternative by plotting the hespdiv sensitivity analysis results using the plot_hsa function. By selecting a new basal subdivision, you can observe how it affects the results of polygon object cross-comparison and the stability of hespdiv clusters and polygons.

Usage

change_base(obj, id)

Arguments

obj

A hsa class object.

id

An index of an alternative subdivision to be used as a new basal subdivision.

Value

The hsa class object with a new basal subdivision.

Author(s)

Liudas Daumantas

See Also

Other functions for hespdiv sensitivity analysis: hsa(), hsa_detailed(), hsa_quant(), hsa_sample_constrained(), plot_cs_hsa(), plot_hsa(), plot_hsa_q()


hespdiv documentation built on May 21, 2026, 5:09 p.m.