create_gif: Create a gif of blok3D

View source: R/create_gif.R

create_gifR Documentation

Create a gif of blok3D

Description

Functions creates a gif of rotating polygons displayed in a currently actively rgl device produced with blok3D

Usage

create_gif(output_file, frames = 90, angle_per_frame = 5, fps = 10)

Arguments

output_file

name and path of output file

frames

integer. Number of frames.

angle_per_frame

numeric. Angle to rotate per frame in degrees.

fps

integer. Frames per second.

Value

No return value. Called for the side effect of saving a GIF of a rotating 3D plot.

Note

You can adjust the size of rgl device window to control the size of gif.

Author(s)

Liudas Daumantas

See Also

Other HespDiv visualization options: blok3d(), dendro(), plot.nullhespdiv(), plot_cs_hsa(), plot_hespdiv(), plot_hsa(), plot_hsa_q(), poly_scheme(), polypop()


hespdiv documentation built on May 21, 2026, 5:09 p.m.