example_hespdiv: Example hespdiv object

example_hespdivR Documentation

Example hespdiv object

Description

A small hespdiv object created from simulated occurrence data with a known boundary at x = 0.45. The object is intended for examples, tests, and demonstrations of plotting and post-processing functions.

Format

A hespdiv object.

Details

The object was generated using simulated coordinates and taxon names. Occurrences on the left and right sides of the artificial boundary share several common taxa but also include side-specific taxa. The exact code used to simulate the dataset and run hespdiv is also demonstrated in the examples of hespdiv function.

Examples

data(example_hespdiv)
plot_hespdiv(example_hespdiv)


hespdiv documentation built on May 21, 2026, 5:09 p.m.