plot_hsa_q: Plot the stability of hespdiv clusters

View source: R/plot_hsa_q.R

plot_hsa_qR Documentation

Plot the stability of hespdiv clusters

Description

This function visualizes the stability of basal subdivision clusters obtained from hsa_quant

Usage

plot_hsa_q(obj, hist = FALSE)

Arguments

obj

The output of hsa_quant (an object of class hsa_quant).

hist

A Boolean value. If FALSE, EPDFs obtained with plot(density(jac.sim)) will be displayed instead of histograms.

Details

The stability of each basal cluster is revealed by the distribution of Jaccard similarity values with the 'analogues' clusters found in alternative hespdiv subdivisions. For example, a unimodal distribution with a peak at high similarity values (>0.8) indicates that the basal hespdiv cluster is stable, even if the polygon boundaries are not. This situation may arise when there is indeed a spatial structure within the data, but there are also wide gaps between sampled regions (or more generally when there is limited spatial data coverage). A unimodal distribution with a peak at medium values (0.4-0.6) and a tail to higher values could also indicate a more persistent spatial structure. On the other hand, a single peak at low values (<0.4) indicates low cluster stability (e.g., bioregion does not exist). Finally, uniform, bimodal, or other more complex distributions may indicate that the stability and existence of the corresponding basal cluster depend on the parameters used in alternative hespdiv calls.

Value

None

Author(s)

Liudas Daumantas

See Also

Other functions for hespdiv sensitivity analysis: change_base(), hsa(), hsa_detailed(), hsa_quant(), hsa_sample_constrained(), plot_cs_hsa(), plot_hsa()

Other HespDiv visualization options: blok3d(), create_gif(), dendro(), plot.nullhespdiv(), plot_cs_hsa(), plot_hespdiv(), plot_hsa(), poly_scheme(), polypop()

Other functions to evaluate hesdpiv cluster stability: hsa_quant()


hespdiv documentation built on May 21, 2026, 5:09 p.m.