poly_scheme: Schematic plot of hespdiv polygons

View source: R/poly_scheme.R

poly_schemeR Documentation

Schematic plot of hespdiv polygons

Description

This function generates a schematic visualization of subdivided territory. It highlights the location of each polygon by displaying their centroids, ID labels, and punctuated lines that connect the polygon centroids with the split-lines that created them. This visualization represents the spatial arrangement of hespdiv polygons within the territory in 2D.

Usage

poly_scheme(obj, segment = TRUE, id = TRUE, seed = 1)

Arguments

obj

A hespdiv object.

segment

A Boolean value. Display the punctuated lines joining the polygon centroids with the split-lines?

id

A Boolean value. Display the IDs of polygons?

seed

An integer value that determines the random set of colors used in visualization of split-lines and polygons.

Value

A ggplot object.

Note

A much clearer way to visualize polygons is by using the blok3D function, with height = "rank". However, a 3D plot is less suitable option for papers.

Author(s)

Liudas Daumantas

See Also

Other HespDiv visualization options: blok3d(), create_gif(), dendro(), plot.nullhespdiv(), plot_cs_hsa(), plot_hespdiv(), plot_hsa(), plot_hsa_q(), polypop()

Examples

poly_scheme(example_hespdiv)


hespdiv documentation built on May 21, 2026, 5:09 p.m.