polypop: Remove polygons from rgl device

View source: R/poly_pop.R

polypopR Documentation

Remove polygons from rgl device

Description

This function allows you to interactively select and remove unwanted polygons from a 3D plot created with the blok3d function.

Usage

polypop(obj, height)

Arguments

obj

The hespdiv object used to create the currently active rgl device with the blok3d function.

height

A character value that indicates the height co-ordinate.

Value

No return value. Called for the interactive modification of a plot created by blok3d

Author(s)

Liudas Daumantas

See Also

Other HespDiv visualization options: blok3d(), create_gif(), dendro(), plot.nullhespdiv(), plot_cs_hsa(), plot_hespdiv(), plot_hsa(), plot_hsa_q(), poly_scheme()


hespdiv documentation built on May 21, 2026, 5:09 p.m.