| blok3d | R Documentation |
This function visualizes HespDiv polygons in 3D space. The height axis corresponds to a chosen column from the "poly.stats" data frame.
blok3d(
obj,
height = "mean",
color.seed = 1,
lines = TRUE,
pnts.col = NULL,
obs = TRUE
)
obj |
An object of the hespdiv class |
height |
A character vector with default value |
color.seed |
An integer that controls the colors of the polygons. Change it to a different number if you want to get a different set of colors. |
lines |
A Boolean value. Do you want split-lines to be displayed over the top of the polygons? |
pnts.col |
A character or numeric vector. Color codes to be used for displaying observations. |
obs |
A Boolean value. Do you want observations to be displayed over the top of the polygons? |
The function opens an rgl device for each selected column of the
poly.stats data frame.
Visualizing values from poly.stats as polygon height can provide
insight into spatial heterogeneity in the analyzed data and its hierarchical
spatial structure.
The height = "rank" option provides a more intuitive way to understand
the position of each polygon in the spatial hierarchy than
poly_scheme().
Because higher-rank polygons are displayed above lower-rank polygons, they may
obscure the view. For this reason, polypop(obj, height) can be used
with the same arguments to interactively select unwanted polygons and remove
them from the actives plot.
No return value. Called for the side effect of producing a 3D plot using the rgl graphics engine.
Liudas Daumantas
Other HespDiv visualization options:
create_gif(),
dendro(),
plot.nullhespdiv(),
plot_cs_hsa(),
plot_hespdiv(),
plot_hsa(),
plot_hsa_q(),
poly_scheme(),
polypop()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.