| change_base | R Documentation |
This function allows you to select a new basal subdivision
from the results of hespdiv sensitivity analysis by specifying its ID. It
provides a convenient way to switch between different basal subdivisions.
You can identify a more stable subdivision alternative by plotting the
hespdiv sensitivity analysis results using the plot_hsa function.
By selecting a new basal subdivision, you can observe how it affects the
results of polygon object cross-comparison and the stability of hespdiv
clusters and polygons.
change_base(obj, id)
obj |
A |
id |
An index of an alternative subdivision to be used as a new basal subdivision. |
The hsa class object with a new basal subdivision.
Liudas Daumantas
Other functions for hespdiv sensitivity analysis:
hsa(),
hsa_detailed(),
hsa_quant(),
hsa_sample_constrained(),
plot_cs_hsa(),
plot_hsa(),
plot_hsa_q()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.