| create_gif | R Documentation |
Functions creates a gif of rotating polygons displayed in a currently actively rgl device produced with blok3D
create_gif(output_file, frames = 90, angle_per_frame = 5, fps = 10)
output_file |
name and path of output file |
frames |
integer. Number of frames. |
angle_per_frame |
numeric. Angle to rotate per frame in degrees. |
fps |
integer. Frames per second. |
No return value. Called for the side effect of saving a GIF of a rotating 3D plot.
You can adjust the size of rgl device window to control the size of gif.
Liudas Daumantas
Other HespDiv visualization options:
blok3d(),
dendro(),
plot.nullhespdiv(),
plot_cs_hsa(),
plot_hespdiv(),
plot_hsa(),
plot_hsa_q(),
poly_scheme(),
polypop()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.