| plot_cs_hsa | R Documentation |
Displays the alternative (subsampled) hespdiv subdivisions and the
basal (original) hespdiv subdivision on one or multiple plots,
illustrating how the split-lines vary across different ranks. Additionally,
for each alternative split-line (which is defined by a start and end coordinate),
the function aggregates identical endpoints and overlays their counts on the plot.
plot_cs_hsa(
obj,
type = 1,
rank = NULL,
col_basal = "gray20",
main,
col_boundary = 7,
col_alternatives = "lightyellow3",
max_lwd = 2.5,
min_lwd = 0.75,
alpha_alt = 0.6
)
obj |
An object of class |
type |
An integer indicating the type of plot. Defaults to 1.
|
rank |
Integer. Optional. When |
col_basal |
Character or numeric specifying the color of basal split-lines
(default |
main |
Character. Title for the plot(s). |
col_boundary |
Character or numeric specifying the color of the outer
(first) polygon boundary (default |
col_alternatives |
Character or numeric specifying the color of alternative
split-lines (default |
max_lwd |
Numeric. The maximum line width for the highest-ranked split-line
(default |
min_lwd |
Numeric. The minimum line width for the lowest-ranked split-line
(default |
alpha_alt |
Numeric in the range |
In type = 1, the function creates a single plot showing all
alternative split-lines overlaid on the first polygon boundary,
plus all basal split-lines of the hespdiv basis object.
In type = 2, the function creates separate plots, each focusing
on polygons of a specific rank, drawing alternative lines in the user-specified
color (with transparency) and the basal line in another color or line width.
If a specific rank is provided, only that rank is plotted.
In both cases, after drawing the alternative split-lines the function
aggregates their endpoints (start and end coordinates) and overlays the
count at each unique coordinate using text().
NULL. The function is called for its side effect of generating
one or more plots.
Other functions for hespdiv sensitivity analysis:
change_base(),
hsa(),
hsa_detailed(),
hsa_quant(),
hsa_sample_constrained(),
plot_hsa(),
plot_hsa_q()
Other HespDiv visualization options:
blok3d(),
create_gif(),
dendro(),
plot.nullhespdiv(),
plot_hespdiv(),
plot_hsa(),
plot_hsa_q(),
poly_scheme(),
polypop()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.