| plot_hespdiv | R Documentation |
This function is used to plot the results obtained with the hespidv
function. The plot showcases subdivisions of the study area by split-lines,
visualizing their performances or rank with colors or line widths. Additionally,
it can display the spatial distribution of observations and number of
observations in each location.
plot_hespdiv(
obj,
type = "color",
n.loc = FALSE,
performance = TRUE,
legend_title = NULL,
title = NULL,
subtitle = NULL,
pnts.col = NULL,
seed = 10
)
obj |
A hespdiv object. |
type |
A character. Either "width" or "color" (default "color"). Determines whether quality of split-lines is expressed by line width or color. |
n.loc |
A Boolean value. Would you like to visualize the number of observations at each location? Only possible, when there are localities with more than one observation. If the type is 'color,' the number of observations is expressed through point sizes. Otherwise, they are expressed using color in a logarithmic scale. |
performance |
logical. TRUE - display split-line performance, FALSE - rank. Displaying rank makes the spatial dendrogram clearer. |
legend_title |
A character value that indicates the title of the legend for the split-lines. The default is built according to the method information available in "obj$call.info". |
title |
A character that indicates the title of the plot. |
subtitle |
A character that indicates the subtitle of the plot. |
pnts.col |
A character or numeric vector providing color codes for data points. |
seed |
An integer value that indicates seed used to randomize the colors
of the split-lines. Only meaningful, when argument |
The return ggplot object can be edited as any other ggplot objects by removing undesired elements, changing theme or overlying the plot with additional elements.
A ggplot object.
Liudas Daumantas
Other HespDiv visualization options:
blok3d(),
create_gif(),
dendro(),
plot.nullhespdiv(),
plot_cs_hsa(),
plot_hsa(),
plot_hsa_q(),
poly_scheme(),
polypop()
plot_hespdiv(example_hespdiv)
plot_hespdiv(example_hespdiv, type = "width")
plot_hespdiv(example_hespdiv, n.loc = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.