| poly_scheme | R Documentation |
This function generates a schematic visualization of subdivided territory. It highlights the location of each polygon by displaying their centroids, ID labels, and punctuated lines that connect the polygon centroids with the split-lines that created them. This visualization represents the spatial arrangement of hespdiv polygons within the territory in 2D.
poly_scheme(obj, segment = TRUE, id = TRUE, seed = 1)
obj |
A hespdiv object. |
segment |
A Boolean value. Display the punctuated lines joining the polygon centroids with the split-lines? |
id |
A Boolean value. Display the IDs of polygons? |
seed |
An integer value that determines the random set of colors used in visualization of split-lines and polygons. |
A ggplot object.
A much clearer way to visualize polygons is by using the blok3D
function, with height = "rank". However, a 3D plot is less suitable
option for papers.
Liudas Daumantas
Other HespDiv visualization options:
blok3d(),
create_gif(),
dendro(),
plot.nullhespdiv(),
plot_cs_hsa(),
plot_hespdiv(),
plot_hsa(),
plot_hsa_q(),
polypop()
poly_scheme(example_hespdiv)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.