| polypop | R Documentation |
This function allows you to interactively select and remove unwanted polygons
from a 3D plot created with the blok3d function.
polypop(obj, height)
obj |
The hespdiv object used to create the currently active rgl
device with the |
height |
A character value that indicates the height co-ordinate. |
No return value. Called for the interactive modification of a
plot created by blok3d
Liudas Daumantas
Other HespDiv visualization options:
blok3d(),
create_gif(),
dendro(),
plot.nullhespdiv(),
plot_cs_hsa(),
plot_hespdiv(),
plot_hsa(),
plot_hsa_q(),
poly_scheme()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.